@@ -49,7 +49,7 @@ def build_index(dirbook) :
     content += '<div align="center" style="vertical-align:bottom">' + "\n"
     content +=("<table border=1 style=\"border-collapse:collapse;\">\n")
     tmstr = strftime("%H:%M",localtime())
-    content +=("<tr style=\"background-color:{};\"><td><a href=\".\">{}({})</a></td><td></td></tr>\n".format("#374F11","Index",tmstr))
+    content +=("<tr style=\"background-color:{};\"><td><a href=\".\">{}({})</a></td><td></td></tr>\n".format("#CCCCCC","Index",tmstr))
     colors = ["#C0C0C0","#B6B6B6","#C6C6C6"]
     ic=0
     for d in sorted(os.listdir(dirbook),reverse=True,key=lambda x:os.path.getmtime(os.path.join(dirbook,x))) :
